aboutsummaryrefslogtreecommitdiffstats
path: root/src/tls/tls_session.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/tls/tls_session.h')
-rw-r--r--src/tls/tls_session.h10
1 files changed, 8 insertions, 2 deletions
diff --git a/src/tls/tls_session.h b/src/tls/tls_session.h
index e44967c00..96ef6514e 100644
--- a/src/tls/tls_session.h
+++ b/src/tls/tls_session.h
@@ -10,6 +10,7 @@
#include <botan/x509cert.h>
#include <botan/tls_version.h>
+#include <botan/tls_suites.h>
#include <botan/tls_magic.h>
#include <botan/secmem.h>
@@ -70,9 +71,14 @@ class BOTAN_DLL Session
Protocol_Version version() const { return m_version; }
/**
* Get the ciphersuite of the saved session
*/
- u16bit ciphersuite() const { return m_ciphersuite; }
+ u16bit ciphersuite_code() const { return m_ciphersuite; }
+
+ /**
+ * Get the ciphersuite info of the saved session
+ */
+ Ciphersuite ciphersuite() const { return Ciphersuite::lookup_ciphersuite(m_ciphersuite); }
/**
* Get the compression method used in the saved session
@@ -70,9 +71,14 @@ class BOTAN_DLL Session
Protocol_Version version() const { return m_version; }
/**
- * Get the ciphersuite of the saved session
+ * Get the ciphersuite code of the saved session
*/